@@ -29,7 +29,7 @@ sub parse_index {
   my @x2_dim;
   
   if (ref $_indexs[0] && Rstats::Func::is_array($r, $_indexs[0])
-    && Rstats::Func::is_logical($r, $_indexs[0]) && Rstats::Func::dim($r, $_indexs[0])->length_value > 1) {
+    && Rstats::Func::is_logical($r, $_indexs[0]) && Rstats::Func::dim($r, $_indexs[0])->get_length > 1) {
     my $x2 = $_indexs[0];
     my $x2_dim_values = Rstats::Func::dim($r, $x2)->values;
     my $x2_values = $x2->values;
@@ -45,7 +45,7 @@ sub parse_index {
     for (my $i = 0; $i < @$x1_dim; $i++) {
       my $_index = $_indexs[$i];
 
-      my $index = defined $_index ? Rstats::Func::to_c($r, $_index) : Rstats::Func::NULL($r);
+      my $index = defined $_index ? Rstats::Func::to_object($r, $_index) : Rstats::Func::NULL($r);
       my $index_values = $index->values;
       if (@$index_values && !Rstats::Func::is_character($r, $index) && !Rstats::Func::is_logical($r, $index)) {
         my $minus_count = 0;
@@ -64,7 +64,7 @@ sub parse_index {
       
       if (!@{$index->values}) {
         my $index_values_new = [1 .. $x1_dim->[$i]];
-        $index = Rstats::Func::new_integer($r, @$index_values_new);
+        $index = Rstats::Func::c_integer($r, @$index_values_new);
       }
       elsif (Rstats::Func::is_character($r, $index)) {
         if (Rstats::Func::is_vector($r, $x1)) {
@@ -82,7 +82,7 @@ sub parse_index {
             croak "Can't find name" unless defined $value;
             push @$index_new_values, $value;
           }
-          $indexs[$i] = Rstats::Func::new_integer($r, @$index_new_values);
+          $indexs[$i] = Rstats::Func::c_integer($r, @$index_new_values);
         }
         elsif (Rstats::Func::is_matrix($r, $x1)) {
           
@@ -96,7 +96,7 @@ sub parse_index {
         for (my $i = 0; $i < @{$index->values}; $i++) {
           push @$index_values_new, $i + 1 if $index_values->[$i];
         }
-        $index = Rstats::Func::new_integer($r, @$index_values_new);
+        $index = Rstats::Func::c_integer($r, @$index_values_new);
       }
       elsif ($index->{_minus}) {
         my $index_value_new = [];
@@ -104,12 +104,12 @@ sub parse_index {
         for my $k (1 .. $x1_dim->[$i]) {
           push @$index_value_new, $k unless grep { $_ == -$k } @{$index->values};
         }
-        $index = Rstats::Func::new_integer($r, @$index_value_new);
+        $index = Rstats::Func::c_integer($r, @$index_value_new);
       }
 
       push @indexs, $index;
 
-      my $count = Rstats::Func::length_value($r, $index);
+      my $count = Rstats::Func::get_length($r, $index);
       push @x2_dim, $count unless $count == 1 && $drop;
     }
     @x2_dim = (1) unless @x2_dim;
